@@ -1,4 +1,4 @@
-/* xzgv 0.8 - picture viewer for X, with file selector.
+/* xzgv - picture viewer for X, with file selector.
  * Copyright (C) 1999-2003 Russell Marks. See main.c for license details.
  *
  * help.c - help viewing, and about box.
@@ -45,8 +45,9 @@ gtk_window_set_position(GTK_WINDOW(about_win),GTK_WIN_POS_CENTER);
 gtk_window_set_modal(GTK_WINDOW(about_win),TRUE);
 
 label=gtk_label_new("xzgv " XZGV_VER " - picture viewer for X with file selector\n"
-                    "Copyright (C) 1999-2003 Russell Marks\n"
-                    "Homepage - http://xzgv.browser.org/");
+                    "Copyright (C) 1999-2005 Russell Marks\n"
+                    "Copyright (C) 2007 Reuben Thomas\n"
+                    "Homepage - http://sourceforge.net/projects/xzgv");
 gtk_box_pack_start(GTK_BOX(vbox),label,TRUE,TRUE,2);
 gtk_widget_show(label);
 
@@ -65,7 +66,7 @@ gtk_widget_grab_focus(button);
 gtk_widget_show(button);
 
 /* also allow escs (even from main window!) */
-gtk_widget_add_accelerator(button,"clicked",gtk_accel_group_get_default(),
+gtk_widget_add_accelerator(button,"clicked",mainwin_accel_group,
                            GDK_Escape,0,0);
 
 
