@@ -1,10 +1,10 @@
-/* xzgv 0.8 - picture viewer for X, with file selector.
+/* xzgv - picture viewer for X, with file selector.
  * Copyright (C) 1999-2003 Russell Marks. See main.c for license details.
  *
  * rcfile.h - protos for rcfile.c and config vars.
  */
 
-#define XZGV_VER	"0.8"
+#define XZGV_VER	"0.9.1"
 
 /* geometry bitmask for mainwin_flags */
 #define GEOM_BITS_X_SET		1
@@ -38,7 +38,6 @@ extern int fullscreen;
 extern int show_tagged;
 extern int fast_recursive_update;
 extern int hicol_dither;
-extern int invert_logo;
 extern int skip_parent;
 extern int click_nextpic;
 extern int mouse_scale_x;
